(exception->json exception
{:keys [project-ns context group severity user version
environment meta]
:as options})(get-hostname)Attempt to get the current hostname.
Attempt to get the current hostname.
(notify exception)(notify exception options)Main interface for manually reporting exceptions. When not :api-key is provided in options, tries to load BUGSNAG_KEY var from enviroment.
Main interface for manually reporting exceptions. When not :api-key is provided in options, tries to load BUGSNAG_KEY var from enviroment.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |