(wrap-bugsnag handler-fn)(wrap-bugsnag handler-fn data)Ring middleware, catches exceptions, reports them to Bugsnag and re-throws the exception.
Ring middleware, catches exceptions, reports them to Bugsnag and re-throws the exception.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |